# ⧊where (awhere): Agents Anywhere

⧊where (pronounced *aware [uh-wehr]*) is an agentic workflow framework.

> THIS PROJECT IS IN ACTIVE DEVELOPMENT. PLEASE CHECK BACK LATER!

---
<span style="font-size:8pt;">Copyright &copy; 2024 Weavers @ Eternal Loom. All rights reserved.</span>